# Qmusic API Wrapper

[![PyPi Package](https://img.shields.io/pypi/v/pypi-project.svg)](https://pypi.org/project/qmusic/)

## Requirements

* Python 3.6+

## Installation

Install with pip `pip install qmusic`


## Description

An unofficial Python Qmusic API Wrapper. You can find the documentation [here](https://github.com/svenskithesource/qmusic/blob/master/CHANGELOG.md).
It will keep working until Qmusic changes their api. In that case I will update it as soon as possible.


## Changelog

See [CHANGELOG.md](https://github.com/svenskithesource/qmusic/blob/master/CHANGELOG.md)

## License

See [LICENSE](https://github.com/svenskithesource/qmusic/blob/master/LICENSE)